@@ -646,6 +646,10 @@ class DirectoryDistributive(Distributive):
              'type': 'bind',
              'target': 'run/',
              'source': '/run'},
+            {'name': 'efivars',
+             'type': 'efivarfs',
+             'target': 'sys/firmware/efi/efivars',
+             'source': 'efivarfs'}
             ]
 
     def __init__(self, directory, parent=None, mdirectory=None):
