@@ -72,15 +72,6 @@ class FileSystemManager():
                  'ssd': [],
                  'compress': None,
                  'compatible': ['ntfs-3g']},
-        'reiserfs': {'defaultopt': defaultOpt,
-                     'format': '/sbin/mkfs.reiserfs',
-                     'formatparam': '{labelparam} -f {device}',
-                     'gpt': '8300',
-                     'label': '-l {labelname}',
-                     'msdos': '83',
-                     'compress': None,
-                     'ssd': [],
-                     'type': ['hdd', 'usb-hdd']},
         'xfs': {'defaultopt': defaultOpt,
                 'format': '/sbin/mkfs.xfs',
                 'formatparam': '{labelparam} -f {device}',
